-- change directory to program location such that relatively addressed resources can be found
parse source  . . pgm
call directory filespec('L', pgm)   -- change to the directory where the program resides


.environment~setEntry("my.app", .directory~new)
-- determine our location and create an URLClassLoader to find resources relative to it
parse source . . s
-- determine path to this Rexx program
appDirectory = filespec("Location", s)   -- determine path to this Rexx program
-- use a java.io.File to to get an URL for the file
jfile = .bsf~new("java.io.File",appDirectory)
urlAppDir = jfile~toUri~toUrl
-- create the URLClassLoader using the appDirectory for resolving resources via it
.my.app~appClzLdr = .bsf~new("java.net.URLClassLoader", bsf.createJavaArrayOf("java.net.URL", urlAppDir))

-- load the FXMLLoader class, save it for multiple usages
.my.app~fxmlLoader = bsf.loadClass("javafx.fxml.FXMLLoader")
-- create Rexx object that will control the FXML set up
.my.app~rexxHandler = .rxDocHandler~new
-- instantiate the abstract JavaFX class, the abstract "start" method will be served by rexxHandler
rxApp = BsfCreateRexxProxy(.my.app~rexxHandler,,"javafx.application.Application")
.my.app~rxApp = rxApp
-- launch the application, invoke "start" and then stay up until the application closes
rxApp~launch(rxApp~getClass, .nil)     -- need to use this version of launch in order to work


::requires "BSF.CLS"    -- get Java support

::class RxDocHandler
::method init

/* loads the fxml document defining the GUI elements, sets up a scene for it and shows it */
::method start    -- will be invoked by the "launch" method
use arg primaryStage  -- we get the primary stage to use for our UI
.my.app~primaryStage = primaryStage -- save the primary stage in our directory

-- use application's URLClassloader to find the resource (returns a URL)
mainSceneFXMLUrl = .my.app~appClzLdr~findResource("DoktorCorona.fxml")
mainSceneFXML    = .my.app~fxmlLoader~load( mainSceneFXMLUrl )   -- load the fxml document

-- create a scene from the FXML DOM and assign it to the primaryStage
.my.app~mainScene = .bsf~new("javafx.scene.Scene", mainSceneFXML) -- create a scene for our document
primaryStage~setScene(.my.app~mainScene)   -- set the stage to our scene
primaryStage~title = "Doktor Corona"

--image
inpStrIcon = .my.app~appClzLdr~getResourceAsStream("image/bsf4oorexx_032.png")
imgIcon = .bsf~new("javafx.scene.image.Image",inpStrIcon)
primaryStage~getIcons~add(imgIcon)-- set application icon

--Show the program
primaryStage~show


